# session_spec.rb
require 'factory_girl'
require_relative '../lib/nessus_api'
require 'nokogiri'

RSpec.configure do |config|
  config.include FactoryGirl::Syntax::Methods
end

describe NessusAPI::Session do
  describe ".new" do
    context 'can connect' do
      it 'does not raise an error' do
        expect{NessusAPI::Session.new().close()}.to_not raise_error()
      end
    end

    context 'cannot connect' do
      it 'responds with an error' do
        expect{NessusAPI::Session.new('256.256.256.256').close}.to raise_error
      end
    end

    context 'bad credentials' do
      it 'responds with an error' do
        expect{NessusAPI::Session.new(ENV['NESSUS_HOST'], nil, nil).close}.to raise_error
      end
    end
  end

  describe ".close" do
    context 'done doing things' do
      it 'returns true' do
        expect{NessusAPI::Session.new.close}.to be_true
      end
    end
  end

  describe ".list" do
    let(:scan) {NessusAPI::Session.new()}
    it 'returns an xml object' do
      expect {scan.scanList.is_a?(Nokogiri::XML::Document)}.to be_true
      scan.close()
    end
  end
end

describe NessusAPI::Scan do
  let(:session) { NessusAPI::Session.new() }
  let(:scan) { NessusAPI::Scan.new('127.0.0.1', 'API Test Scan', '-9') }

  describe ".new" do
    it 'to have a uuid' do
      expect{scan.uuid}.to_not be_nil()
    end
  end

  describe ".pause" do
    it 'returns true' do
      expect {scan.pause}.to be_true
    end
  end

  describe ".resume" do
    it 'returns true' do
      expect {scan.resume}.to be_true
    end
  end

  describe ".stop" do
    it 'returns true' do
      expect {scan.stop}.to be_true
    end
  end

  describe ".list" do
    it 'returns a nokogiri object' do
      expect {NessusAPI::Scan.list.is_a?(Nokogiri::XML::Document)}.to be_true
    end
  end
end

describe NessusAPI::Template do
  let(:session) {NessusAPI::Session.new()}
  let(:template) {NessusAPI::Template.new('Test Template', '-9', '127.0.0.1')}
  describe ".new" do
    it 'does not raise an error' do
      expect {template.is_a?(NessusAPI::Template)}.to be_true
    end
  end

  describe ".edit" do
    it 'returns true' do
      expect {template.edit('Test Template', 'Test 2: Test Harder', '-9',
                            '127.0.0.1')}.to be_true
    end
  end

  describe '.launch' do
    it 'returns true' do
      expect {template.launch}.to be_true
    end
  end

  describe '.delete' do
    it 'returns true' do
      expect {template.delete}.to be_true
    end
  end
end
